@@ -21,7 +21,7 @@
  *           Fax: +49 7123 / 14892
  *
  *
- *  $Id: dbdimp.h,v 1.2 1999/01/05 22:30:55 joe Exp $
+ *  $Id: dbdimp.h,v 1.1.1.1.2.2 1999/05/23 11:46:56 joe Exp $
  */
 
 /*
@@ -73,6 +73,8 @@ enum av_attribs {
     AV_ATTRIB_LENGTH,
     AV_ATTRIB_IS_NUM,
     AV_ATTRIB_TYPE_NAME,
+    AV_ATTRIB_PRECISION,
+    AV_ATTRIB_SCALE,
 #ifdef DBD_MYSQL
     AV_ATTRIB_MAX_LENGTH,
     AV_ATTRIB_IS_KEY,
@@ -116,7 +118,6 @@ struct imp_dbh_st {
     dbh_t svsock;           /*  socket number for msql, &mysql for
 			     *  mysql
 			     */
-    int compression;        /*  Using compression.  */
 };
 
 
@@ -156,13 +157,9 @@ struct imp_sth_st {
     int   insertid;       /* ID of auto insert                      */
     imp_sth_ph_t* params; /* Pointer to parameter array             */
     AV* av_attr[AV_ATTRIB_LAST];/*  For caching array attributes        */
-#ifdef DBD_MYSQL
     int   use_mysql_use_result;  /*  TRUE if execute should use     */
                           /* mysql_use_result rather than           */
                           /* mysql_store_result */
-#else
-  bool optimize;	  /* For Msql */
-#endif
 };
 
 
@@ -171,6 +168,8 @@ struct imp_sth_st {
  *
  * These defines avoid name clashes for multiple statically linked DBD's	*/
 #ifdef DBD_MYSQL
+#define MyLogin			mysql_dr_login
+#define MyConnect		mysql_dr_connect
 #define dbd_init		mysql_dr_init
 #define dbd_db_login		mysql_db_login
 #define dbd_db_do		mysql_db_do
@@ -198,7 +197,11 @@ struct imp_sth_st {
 #define mymsql_constant         mysql_constant
 #define do_warn			mysql_dr_warn
 #define do_error		mysql_dr_error
+#define dbd_db_type_info_all    mysql_db_type_info_all
+#define dbd_db_quote            mysql_db_quote
 #elif defined(DBD_MSQL1)
+#define MyLogin			msql1_dr_login
+#define MyConnect		msql1_dr_connect
 #define dbd_init		msql1_dr_init
 #define dbd_db_login		msql1_db_login
 #define dbd_db_do		msql1_db_do
@@ -226,7 +229,12 @@ struct imp_sth_st {
 #define mymsql_constant         msql1_constant
 #define do_warn			msql1_dr_warn
 #define do_error		msql1_dr_error
+#define dbd_dr_types            msql1_dr_types
+#define dbd_db_type_info_all    msql1_db_type_info_all
+#define dbd_db_quote            msql1_db_quote
 #else
+#define MyLogin			msql_dr_login
+#define MyConnect		msql_dr_connect
 #define dbd_init		msql_dr_init
 #define dbd_db_login		msql_db_login
 #define dbd_db_do		msql_db_do
@@ -254,6 +262,9 @@ struct imp_sth_st {
 #define mymsql_constant         msql_constant
 #define do_warn			msql_dr_warn
 #define do_error		msql_dr_error
+#define dbd_dr_types            msql_dr_types
+#define dbd_db_type_info_all    msql_db_type_info_all
+#define dbd_db_quote            msql_db_quote
 #endif
 
 #include <dbd_xsh.h>
@@ -261,12 +272,12 @@ void	 do_error _((SV* h, int rc, char *what));
 SV	*dbd_db_fieldlist _((result_t res));
 
 void    dbd_preparse _((imp_sth_t *imp_sth, SV *statement));
-#ifdef DBD_MYSQL
 int dbd_st_internal_execute(SV*, SV*, SV*, int, imp_sth_ph_t*, result_t*,
 			    dbh_t, int);
-#else
-int dbd_st_internal_execute(SV*, SV*, SV*, int, imp_sth_ph_t*, result_t*,
-			    dbh_t);
-#endif
+AV* dbd_db_type_info_all _((SV* dbh, imp_dbh_t* imp_dbh));
+SV* dbd_db_quote(SV*, SV*, SV*);
+extern int MyConnect(dbh_t*, char*, char*, char*, char*, char*, char*,
+		     imp_dbh_t*);
+
 
 extern int MysqlReconnect(SV*);
