@@ -103,7 +103,7 @@ sub new {
 ############################################################################
 
 sub Initialize {
-    my($self) = @_;
+    my($self, $options) = @_;
 
     my @msqldirs = qw{/usr/local/Hughes /usr/local/Minerva /usr/local
 		      /usr/mSQL /opt/mSQL /usr};
@@ -114,10 +114,19 @@ sub Initialize {
     }
 
     my $headerdir;
-    ($headerdir, $gooddir) = $self->SearchHeaders
-	(\@gooddirs, \@msqldirs, ["include/msql.h"]);
-    my($libdir) = $self->SearchLibs
-	(\@gooddirs, \@msqldirs, ["lib/libmsql.a"]);
+    if (exists($options->{'msql-incdir'})) {
+	$headerdir = $options->{'msql-incdir'};
+    } else {
+	($headerdir, $gooddir) = $self->SearchHeaders
+	    ($options, \@gooddirs, \@msqldirs, ["include/msql.h"]);
+    }
+    my $libdir;
+    if (exists($options->{'msql-libdir'})) {
+	$options->{'msql-libdir'};
+    } else {
+	$libdir = $self->SearchLibs
+	    ($options, \@gooddirs, \@msqldirs, ["lib/libmsql.a"]);
+    }
 
     my $extralibs = "";
     my $linkwith = "";
