@@ -17,7 +17,7 @@ use vars qw($QUIET @ISA @EXPORT @EXPORT_OK $VERSION $db_errstr);
 $db_errstr = '';
 $QUIET  = 0;
 @ISA    = qw(DBI); # Inherits Exporter and DynaLoader via DBI
-$VERSION = '1.21_15';
+$VERSION = '1.2200';
 
 # @EXPORT is a relict from old times...
 @EXPORT = qw(
@@ -91,20 +91,24 @@ sub DESTROY {
     my $self = shift;
     my $dbh = $self->{'dbh'};
     if ($dbh) {
-	local $SIG{__WARN__} = sub { };
+	local $SIG{'__WARN__'} = sub {};
 	$dbh->disconnect();
     }
 }
 
 sub selectdb ($$) {
     my($self, $db) = @_;
-    my($dsn) = "DBI:mSQL:database=$db:host=" . $self->{'host'};
-    my($dbh) = DBI->connect($dsn, $self->{'user'}, $self->{'password'});
+    my $dsn = "DBI:mSQL:database=$db:host=" . $self->{'host'};
+    my $dbh = DBI->connect($dsn, $self->{'user'}, $self->{'password'});
     if (!$dbh) {
 	$db_errstr = $self->{'errstr'} = $DBI::errstr;
 	$self->{'errno'} = $DBI::err;
 	undef;
     } else {
+	if ($self->{'dbh'}) {
+	    local $SIG{'__WARN__'} = sub {};
+	    $self->{'dbh'}->disconnect();
+	}
 	$self->{'dbh'} = $dbh;
 	$self->{'db'} = $db;
 	$self;
@@ -845,6 +849,7 @@ be supported for a long time. But it's a dead end. I expect in the
 medium term, that the DBI efforts result in a richer module family
 with better support and more functionality. Alligator maintains an
 interesting page on the DBI development:
-http://www.arcana.co.uk/technologia/perl/DBI
+
+    http://www.symbolstone.org/technology/perl/DBI
 
 =cut
