@@ -1,6 +1,6 @@
 #   Our beloved Emacs will give us -*- perl -*- mode :-)
 #
-#   $Id: dbd.pm.in,v 1.1.1.1.2.2 1998/12/30 00:28:15 joe Exp $
+#   $Id: dbd.pm.in,v 1.1.1.1.2.7 1999/05/23 11:46:56 joe Exp $
 #
 #   Copyright (c) 1994,1995,1996,1997 Alligator Descartes, Tim Bunce
 #
@@ -16,7 +16,7 @@ use DynaLoader();
 use Carp ();
 @ISA = qw(DynaLoader);
 
-$VERSION = '2.03_15';
+$VERSION = '2.0400';
 
 bootstrap DBD::mysql $VERSION;
 
@@ -229,7 +229,7 @@ sub _SelectDB ($$) {
 }
 
 {
-    my $names = ['TABLE_QUALIFIER', 'TABLE_OWNER', 'TABLE_NAME',
+    my $names = ['TABLE_CAT', 'TABLE_SCHEM', 'TABLE_NAME',
 		 'TABLE_TYPE', 'REMARKS'];
 
     sub table_info ($) {
@@ -324,10 +324,74 @@ code changes.
 
 =head1 DESCRIPTION
 
-<DBD::mysql> and <DBD::mSQL> are the Perl5 Database Interface drivers for
-the mysql, mSQL 1.I<x> and mSQL 2.I<x> databases. The drivers are part
+B<DBD::mysql> and B<DBD::mSQL> are the Perl5 Database Interface drivers
+for the mysql, mSQL 1.I<x> and mSQL 2.I<x> databases. The drivers are part
 of the I<Msql-Mysql-modules> package.
 
+In other words: DBD::mSQL and DBD::mysql are an interface between the Perl
+programming language and the mSQL or mysql programming API that come with
+the mSQL any mysql relational database management systems. Most functions
+provided by the respective programming API's are supported. Some
+rarely used functions are missing, mainly because noone ever requested
+them. :-)
+
+In what follows we first discuss the use of DBD::mysql and DBD::mSQL,
+because this is what you will need the most. For installation, see the
+sections on L<INSTALLATION>, L<WIN32 INSTALLATION>, L<KNOWN PROBLEMS>
+and L<KNOWN BUGS> below. See L<EXAMPLE> for a simple example below.
+
+From perl you activate the interface with the statement
+
+    use DBI;
+
+After that you can connect to multiple mSQL or MySQL database servers
+and send multiple queries to any of them via a simple object oriented
+interface. Two types of objects are available: database handles and
+statement handles. Perl returns a database handle to the connect
+method like so:
+
+  $dbh = DBI->connect("DBI:mSQL:database=$db;host=$host",
+		      undef, undef, {RaiseError => 1});
+
+or
+
+  $dbh = DBI->connect("DBI:mysql:database=$db;host=$host",
+		      $user, $password, {RaiseError => 1});
+
+Once you have connected to a database, you can can execute SQL
+statements with:
+
+  my $query = sprintf("INSERT INTO foo VALUES (%d, %s)",
+		      $number, $dbh->quote("name"));
+  $dbh->do($query);
+
+See L<DBI(3)> for details on the quote and do methods. An alternative
+approach is
+
+  $dbh->do("INSERT INTO foo VALUES (?, ?)", undef,
+	   $number, $name);
+
+in which case the quote method is executed automatically. See also
+the bind_param method in L<DBI(3)>. See L<DATABASE HANDLES> below
+for more details on database handles.
+
+If you want to retrieve results, you need to create a so-called
+statement handle with:
+
+  $sth = $dbh->prepare("SELECT * FROM $table");
+  $sth->execute();
+
+This statement handle can be used for multiple things. First of all
+you can retreive a row of data:
+
+  my $row = $sth->fetchow_hashref();
+
+If your table has columns ID and NAME, then $row will be hash ref with
+keys ID and NAME. See L<STATEMENT HANDLES> below for more details on
+statement handles.
+
+But now for a more formal approach:
+
 
 =head2 Class Methods
 
@@ -726,7 +790,8 @@ equivalent of a statement handle. These are:
 =item LISTFIELDS $table
 
 Returns a statement handle that describes the columns of $table.
-Ses the docs of msqlListFields or mysql_list_fields for details.
+Ses the docs of msqlListFields or mysql_list_fields (C API) for
+details.
 
 =item LISTINDEX $table $index
 
@@ -736,6 +801,7 @@ of table $table. See the docs of msqlListIndex for details.
 =back
 
 
+
 =head1 COMPATIBILITY ALERT
 
 The statement attribute I<TYPE> has changed its meaning, as of
@@ -1012,7 +1078,408 @@ to configure. See the section on I<How to make a threadsafe client> in
 the manual.
 
 
-=head1 BUGS
+=head1 EXAMPLE
+
+  #!/usr/bin/perl
+
+  use strict;
+  use DBI();
+
+  # Connect to the database.
+  my $dbh = DBI->connect("DBI:mysql:database=test;host=localhost",
+                         "joe", "joe's password",
+                         {'RaiseError' => 1});
+
+  # Drop table 'foo'. This may fail, if 'foo' doesn't exist.
+  eval { $dbh->do("DROP TABLE foo") };
+  print "Dropping foo failed: $@\n" if $@;
+
+  # Create a new table 'foo'. This must not fail, thus we don't
+  # catch errors.
+  $dbh->do("CREATE TABLE foo (id INTEGER, name VARCHAR(20)");
+
+  # INSERT some data into 'foo'. We are using $dbh->quote() for
+  # quoting the name.
+  $dbh->do("INSERT INTO foo VALUES (1, " . $dbh->quote("Tim") . ")");
+
+  # Same thing, but using placeholders
+  $dbh->do("INSERT INTO foo VALUES (?, ?)", undef, 2, "Jochen");
+
+  # Now retrieve data from the table.
+  my $sth = $dbh->prepare("SELECT * FROM foo");
+  $sth->execute();
+  while (my $ref = $sth->fetchrow_hashref()) {
+    print "Found a row: id = $ref->{'id'}, name = $ref->{'name'}\n";
+  }
+  $sth->finish();
+
+  # Disconnect from the database.
+  $dbh->disconnect();
+
+
+=head1 INSTALLATION
+
+Windows users may skip this section and pass over to L<WIN32
+INSTALLATION> below. Others, go on reading.
+
+First you need to install the DBI module. For using I<dbimon>, a
+simple DBI shell it is recommended to install Data::ShowTable another
+Perl module.
+
+I recommend trying automatic installation via the CPAN module. Try
+
+  perl -MCPAN -e shell
+
+If you are using the CPAN module for the first time, it will prompt
+you a lot of questions. If you finally receive the CPAN prompt, enter
+
+  install Bundle::DBD::mSQL
+
+or
+
+  install Bundle::DBD::mysql
+
+If this fails (which may be the case for a number of reasons, for
+example because you are behind a firewall or don't have network
+access), you need to do a manual installation. First of all you
+need to fetch the archives from any CPAN mirror, for example
+
+  ftp://ftp.funet.fi/pub/languages/perl/CPAN/modules/by-module
+
+The following archives are required (version numbers may have
+changed, I choose those which are current as of this writing):
+
+  DBI/DBI-1.06.tar.gz
+  Data/Data-ShowTable-3.3.tar.gz
+  DBD/Msql-Mysql-modules-1.2017.tar.gz
+
+Then enter the following commands:
+
+  gzip -cd DBI-1.06.tar.gz | tar xf -
+  cd DBI-1.06
+  perl Makefile.PL
+  make
+  make test
+  make install
+
+  cd ..
+  gzip -cd Data-ShowTable-3.3.tar.gz | tar xf -
+  cd Data-ShowTable-3.3
+  perl Makefile.PL
+  make
+  make install  # Don't try make test, the test suite is broken
+
+  cd ..
+  gzip -cd Msql-Mysql-modules-1.2017.tar.gz | tar xf -
+  cd Msql-Mysql-modules-1.2017
+  perl Makefile.PL
+  make
+  make test
+  make install
+
+During "perl Makefile.PL" you will be prompted some questions. In
+particular you have to choose the installed drivers (MySQL, mSQL2
+and/or mSQL1). The MySQL driver will be called DBD::mysql, a single
+mSQL driver will be called DBD::mSQL. If you want to support both
+mSQL1 and mSQL2, they former will be DBD::mSQL1.
+
+Other questions are the directories with header files and libraries.
+For example, of your file F<mysql.h> is in F</usr/include/mysql/mysql.h>,
+then enter the header directory F</usr>, likewise for
+F</usr/lib/mysql/libmysqlclient.a> or F</usr/lib/libmysqlclient.so>.
+For mSQL go looking for F<msql.h> (typically in F</usr/include/msql.h>
+and F<libmsql.a> (probably in F</usr/lib/libmsql.a>).
+
+See the L<KNOWN PROBLEMS> section below if you encounter any problems
+within "make" or "make test".
+
+
+=head1 WIN32 INSTALLATION
+
+I have never attempted to install DBD::mSQL under Win32, so this is only
+for MySQL. If anyone succeeds, please let me know what you did.
+
+If you are using the ActiveState port of Perl, there's a binary
+package of DBD::mysql available at www.tcx.se, see the download
+page. This can be installed with I<ppm>. Otherwise it is recommended
+to use a binary distribution of Perl that already includes DBD::mysql.
+For example you find one at www.tcx.se.
+
+Otherwise you definitely *need* a C compiler. And it *must* be the same
+compiler that was being used for compiling Perl itself. If you don't
+have a C compiler, the file README.win32 from the Perl source
+distribution tells you where to obtain freely distributable C compilers
+like egcs or gcc. The Perl sources are available on any CPAN mirror in
+the src directory, for example
+
+    ftp://ftp.funet.fi/pub/languages/perl/CPAN/src/latest.tar.gz
+
+I recommend using the win32clients package for installing DBD::mysql
+under Win32, available for download on www.tcx.se. The following steps
+have been required for me:
+
+=over 8
+
+=item -
+
+Extract sources into F<C:\>. This will create a directory F<C:\mysql>
+with subdirectories include and lib.
+
+IMPORTANT: Make sure this subdirectory is not shared by other TCX
+files! In particular do *not* store the MySQL server in the same
+directory. If the server is already installed in F<C:\mysql>,
+choose a location like F<C:\tmp>, extract the win32clients there.
+Note that you can remove this directory entirely once you have
+installed the Msql-Mysql-modules.
+
+=item -
+
+Extract the Msql-Mysql-modules sources into another directory, for
+example F<C:\src\siteperl>
+
+=item -
+
+Open a DOS shell and change directory to F<C:\src\siteperl>.
+
+=item -
+
+The next step is only required if you repeat building the modules: Make
+sure that you have a clean build tree by running
+
+  nmake realclean
+
+If you don't have VC++, replace nmake with your flavour of make. If
+error messages are reported in this step, you may safely ignore them.
+
+=item -
+
+Run
+
+  perl Makefile.PL
+
+which will prompt you for some settings. The really important ones are:
+
+  Which DBMS do you want to use?
+
+enter a 1 here (MySQL only), and
+
+  Where is your mysql installed? Please tell me the directory that
+  contains the subdir include.
+
+where you have to enter the win32clients directory, for example
+F<C:\mysql> or F<C:\tmp\mysql>.
+
+=item -
+
+Continued in the usual way:
+
+  nmake
+  nmake install
+
+=back
+
+See the first section of L<KNOWN PROBLEMS> below.
+
+If you want to create a PPM package for the ActiveState Perl version, then
+modify the above steps as follows: Run
+
+  perl Makefile.PL NAME=DBD-mysql BINARY_LOCATION=DBD-mysql.tar.gz
+  nmake ppd
+  nmake
+
+Once that is done, use tar and gzip (for example those from the CygWin32
+distribution) to create an archive:
+
+  mkdir x86
+  tar cf x86/DBD-mysql.tar blib
+  gzip x86/DBD-mysql.tar
+
+Put the files x86/DBD-mysql.tar.gz and DBD-mysql.ppd onto some WWW server
+and install them by typing
+
+  install http://your.server.name/your/directory/DBD-mysql.ppd
+
+in the PPM program.
+
+
+=head1 KNOWN PROBLEMS
+
+=over 8
+
+=item 1.)
+
+If the MySQL binaries are compiled with gcc or egcs (as the precompiled
+binaries are), but your Perl is using another compiler, it is likely that
+you receive an error message like the following when running "make test":
+
+  t/00base............install_driver(mysql) failed: Can't load
+  '../blib/arch/auto/DBD/mysql/mysql.so' for module DBD::mysql:
+  ../blib/arch/auto/DBD/mysql/mysql.so: undefined symbol: _umoddi3
+  at /usr/local/perl-5.005/lib/5.005/i586-linux-thread/DynaLoader.pm
+  line 168.
+
+This means, that your linker doesn't include libgcc.a. You have the
+following options:
+
+=over 12
+
+=item a)
+
+Either recompile Perl or Mysql, it doesn't matter which. The important
+thing is that you use the same compiler for both. This is definitely
+the recommended solution in the long term.
+
+=item b)
+
+A simple workaround is to include libgcc.a manually. Do a "make clean"
+and "make" and in the output wait for a line like
+
+  LD_RUN_PATH="/usr/lib/mysql:/lib" egcs -o
+  ../blib/arch/auto/DBD/mysql/mysql.so  -shared -L/usr/local/lib
+  dbdimp.o mysql.o -L/usr/lib/mysql -L/usr/lib/mysql -lmysqlclient
+  -lm
+
+Repeat the same line in the shell by adding
+
+  -L/usr/lib/gcc-lib/i386-redhat-linux/gcc-2.7.2.3 -lgcc
+
+where the directory is the location of libgcc.a. The best choice
+for locating this file is executing
+
+  gcc --print-libgcc-file
+
+or
+
+  gcc -v
+
+=back
+
+
+=item 2.)
+
+There are known problems with shared versions of libmysqlclient, at
+least on some Linux boxes. If you receive an error message similar to
+
+  install_driver(mysql) failed: Can't load
+  '/usr/lib/perl5/site_perl/i586-linux/auto/DBD/mysql/mysql.so'
+  for module DBD::mysql: File not found at
+  /usr/lib/perl5/i586-linux/5.00404/DynaLoader.pm line 166
+
+then this error message can be misleading: It's not mysql.so that fails
+being loaded, but libmysqlclient.so!
+
+As a workaround, recompile the Msql-Mysql-modules with
+
+  perl Makefile.PL --static --config
+  make
+  make test
+  make install
+
+This option forces linkage against the static libmysqlclient.a.
+
+
+=item 3.)
+
+By default mSQL2 is installed to allow local access only. This can break
+the test scripts akmisc.t, msql1.t and msql2.t. You might notice a message
+like
+
+  t/akmisc............Can't connect to MSQL server on localhost at
+  t/akmisc.t line 131
+  Cannot connect: Can't connect to MSQL server on localhost
+  It looks as if your server (on localhost) is not up and running.
+  This test requires a running server.
+  Please make sure your server is running and retry.
+  dubious
+  Test returned status 10 (wstat 2560, 0xa00)
+
+If this is the case, try to change the value of "Remote_Access" in
+your F<msql.conf> file to "True". If the value was set intentionally,
+you might restore the old value after the tests ran ok.
+
+
+=item 4.)
+
+If linking fails under Win32 because of a missing symbol
+pthread_cond_init, apply the following patch to dbd/dbdimp.c:
+
+  *** dbd/dbdimp.c.orig	Wed Sep 23 14:39:33 1998
+  --- dbd/dbdimp.c	Fri Oct 02 10:37:16 1998
+  ***************
+  *** 1708,1712 ****
+  --- 1709,1720 ----
+      }
+      return TRUE;
+    }
+  + 
+  + #if !defined(_UNIX_)  &&  defined(WIN32)
+  + int pthread_cond_init()
+  + {
+  +   return 0;
+  + }
+  + #endif
+
+    #endif
+
+(I could make this part of the source distribution, but I think this is an
+ugly hack and hopefully Monty will fix the missing symbol in the next
+release of MyODBC.)
+
+
+=item 5.)
+
+Recent versions of mSQL have a bug that appears in the test script
+t/40bindparam.t:
+
+  > Date: Tue, 14 Jul 1998 00:59:07 +0200 (CEST)
+  > From: Barry Lagerweij <barry@euromedia.nl>
+  > To: weder@arch.ethz.ch
+  > Cc: msql-jdbc@list.imaginary.com, support@hughes.com.au
+  > Subject: [MSQL-JDBC]: mSQL 2.0.4.1 ORDER BY bug
+  > 
+  > Hello Andreas,
+  > 
+  > I read your message concerning the mSQL ORDER BY bug, since I suffered
+  > from the same problems.
+  > 
+  > I dived into the source, and came up with a solution: in avl_tree.c, the
+  > copy/compare functions do not take the first (aka NULL) byte into account.
+  > mSQL 2.0.4.1 supports NULL values, but these are not handled correctly in
+  > the index functions. The following patch corrects this :
+  > 
+  > ----------------cut here----------------
+  > 
+  > *** avl_tree.c.orig     Mon Jul 13 14:22:31 1998
+  > --- avl_tree.c  Mon Jul 13 15:37:59 1998
+  > ***************
+  > *** 218,223 ****
+  > --- 218,224 ----
+  >                 *dst;
+  >         avltree *tree;
+  >   {
+  > +       *dst++ = *src++;
+  >         switch(tree->sblk->keyType)
+  >         {
+  >                 case AVL_INT:
+  > ***************
+  > *** 529,534 ****
+  > --- 530,538 ----
+  >                 *v2;
+  >         avltree *tree;
+  >   {
+  > +       int     i;
+  > +
+  > +       if ((i = (*v1++ - *v2++)) != 0) return(i);
+  >         switch(tree->sblk->keyType)
+  >         {
+  >                 case AVL_INT:
+  > 
+  > -------------cut here------------------
+
+=back
+
+
+=head1 KNOWN BUGS
 
 The I<port> part of the first argument to the connect call is
 implemented in an unsafe way when using mSQL. In fact it is just
@@ -1021,62 +1488,48 @@ call. If another connect call uses another port and the handles
 are used simultaneously, they will interfere. I doubt that this
 will ever change.
 
-Msql-2.0.4 and 2.0.4.1 contain a bug that makes ORDER BY and hence
-the test script C<t/40bindparam> fail. To verify, if this is the
-case for you, do a
-
-	cd Msql
-	perl -w -I../blib/lib -I../blib/arch t/40bindparam.t
-
-If something is wrong, the script ought to print a number of id's and
-names. If the id's aren't in order, it is likely, that your mSQL has
-a bug. See the INSTALL file for a patch.
-
 
 =head1 AUTHORS
 
-B<DBD::mSQL> has been primarily written by Alligator Descartes
-(I<descarte@arcana.co.uk>), who has been aided and abetted by Gary
-Shea, Andreas Koenig and Tim Bunce amongst others. Apologies if your
-name isn't listed, it probably is in the file called
-'Acknowledgments'. As of version 0.80 the maintainer is Andreas Knig.
-Version 2.00 is an almost complete rewrite by Jochen Wiedmann.
+The current versions of B<DBD::mSQL> and B<DBD::mysql> is almost
+completely written by Jochen Wiedmann (I<joe@ispsoft.de>). The
+first version's author was Alligator Descartes(I<descarte@symbolstone.org>),
+who has been aided and abetted by Gary Shea, Andreas Knig and Tim Bunce
+amongst others.
+
+The B<Msql> and B<Mysql> modules have originally been written by
+Andreas Knig <koenig@kulturbox.de>. The current version, mainly
+an emulation layer, is from Jochen Wiedmann.
 
 
 =head1 COPYRIGHT
 
-This module is Copyright (c)1997 Jochen Wiedmann, with code portions
-Copyright (c)1994-1997 their original authors. This module is
-released under the 'Artistic' license which you can find in the perl
-distribution.
+This module is Copyright (c) 1997-1999 Jochen Wiedmann, with code
+portions Copyright (c)1994-1997 their original authors. This module is
+released under the same license as Perl itself. See the Perl README
+for details.
 
-This document is Copyright (c)1997 Alligator Descartes. All rights
-reserved.  Permission to distribute this document, in full or in part,
-via email, Usenet, ftp archives or http is granted providing that no
-charges are involved, reasonable attempt is made to use the most
-current version and all credits and copyright notices are retained (
-the I<AUTHOR> and I<COPYRIGHT> sections ).  Requests for other
-distribution rights, including incorporation into commercial products,
-such as books, magazine articles or CD-ROMs should be made to
-Alligator Descartes <I<descarte@arcana.so.uk>>.
 
+=head1 MAILING LIST SUPPORT
 
 =head1 MAILING LIST SUPPORT
 
 This module is maintained and supported on a mailing list,
 
-    msql-mysql-modules@tcx.se
+    msql-mysql-modules@lists.mysql.com
 
-To subscribe to this list, send a mail with the words
+To subscribe to this list, send a mail to
 
-    subscribe msql-mysql-modules
+    msql-mysql-modules-subscribe@lists.mysql.com
 
 or
 
-    subscribe msql-mysql-modules-digest
+    msql-mysql-modules-digest-subscribe@lists.mysql.com
+
+Mailing list archives are available at
+
+    http://www.progressive-comp.com/Lists/?l=msql-mysql-modules
 
-in the first line of the body to mdomo@tcx.se. A mailing list archive is
-in preparation.
 
 Additionally you might try the dbi-user mailing list for questions about
 DBI and its modules in general. Subscribe via
@@ -1095,7 +1548,7 @@ Mailing list archives are at
 Additional information on the DBI project can be found on the World
 Wide Web at the following URL:
 
-    http://www.arcana.co.uk/technologia/perl/DBI
+    http://www.symbolstone.org/technology/perl/DBI
 
 where documentation, pointers to the mailing lists and mailing list
 archives and pointers to the most current versions of the modules can
