@@ -7,7 +7,7 @@ package Mysql::Statement;
 use strict;
 use vars qw($OPTIMIZE $VERSION $AUTOLOAD);
 
-$VERSION = '1.21_15';
+$VERSION = '1.2200';
 
 $OPTIMIZE = 0; # controls, which optimization we default to
 
@@ -70,28 +70,33 @@ sub maxlength  {
     my $result;
     if (!($result = $sth->{'mysql_maxlength'})) {
 	$result = [];
-	my ($l);
-	for (0..$sth->numfields-1) {
-	    $$result[$_] = 0;
+	for (my $i = 0;  $i < $sth->numfields();  $i++) {
+	    $result->[$i] = 0;
 	}
 	$sth->dataseek(0);
-	my($col, @row, $i);
-	while (@row = $sth->fetchrow) {
-	    for ($i = 0;  $i < @row;  $i++) {
-		$col = $row[$i];
-		my($s) = defined $col ? unctrl($col) : "NULL";
-		# New in 2.0: a string is longer than it should be
-		if (defined &Msql::TEXT_TYPE  &&
-		    $sth->type->[$i] == &Msql::TEXT_TYPE &&
-		    CORE::length($s) > $sth->length->[$i] + 5) {
-		    my $l = CORE::length($col);
-		    substr($s,$sth->length->[$i]) = "...($l)";
-		}
-		if (CORE::length($s) > $$result[$i]) {
-		    $$result[$i] = CORE::length($s);
+	my $numRows = $sth->numrows();
+	for (my $j = 0;  $j < $numRows;  $j++) {
+	    my @row = $sth->fetchrow;
+	    for (my $i = 0;  $i < @row;  $i++) {
+		my $col = $row[$i];
+		my $s;
+		if (defined($col)) {
+		    $s = unctrl($col);
+		    my $l = CORE::length($s);
+		    # New in 2.0: a string is longer than it should be
+		    if (defined &Msql::TEXT_TYPE  &&
+			$sth->type->[$i] == &Msql::TEXT_TYPE  &&
+			$l > $sth->length->[$i] + 5) {
+			substr($s,$sth->length->[$i]) = "...($l)";
+			$l = CORE::length($s);
+		    }
+		    $result->[$i] = $l if $l > $result->[$i];
+		} else {
+		    $s = "NULL";
 		}
 	    }
 	}
+	$sth->dataseek(0);
     }
     return wantarray ? @$result : $result;
 }
@@ -124,13 +129,6 @@ sub unctrl {
     $x;
 }
 
-sub optimize {
-    my($self,$arg) = @_;
-    if (defined $arg) {
-	$OPTIMIZE = $arg;
-    }
-    $OPTIMIZE;
-}
 
 sub as_string {
     my($sth) = @_;
